@@ -7,6 +7,7 @@ If a supported data format is used, Entry can load the data.
 """
 from datetime import datetime as dt
 from dateutil.relativedelta import relativedelta as rd
+from uuid import uuid4
 
 from sqlalchemy import Column, ForeignKey, event
 from sqlalchemy import Integer, String, Boolean, DateTime
@@ -49,6 +50,12 @@ class Entry(Base):
     ----------
     id : int
         Unique id of the record. If not specified, the database will assign it.
+    uuid : str
+        .. versionadded:: 0.1.9
+
+        Version 4 UUID string to identify the Entry across installations. 
+        This field is read-only and will be assigned on creation. It is primarily 
+        used to export Entry into ISO19115 metadata.
     title : str
         A full title (512) to describe the datasource as well as possible.
         The truncated title (first 25 signs) is usually used to print an 
@@ -91,6 +98,15 @@ class Entry(Base):
         If latest_version_id is None, the Entry is the most recent one and 
         database operations that find multiple entries will in a future release 
         filter to 'version duplicates'.
+    is_partial : bool
+        .. versionadded:: 0.1.10
+        If an Entry is partial, it is not self-contained and **has** to be part 
+        of a :class:`EntryGroup <metacatalog.models.EntryGroup>` of type 
+        composite. 
+        .. note::
+            To make it possbile to add partial Entrys via the models submodule, 
+            The Entry class itself will  **not** check integrity. This has to 
+            be done on adding partial Entry records, or by checking the database
     comment : str
         Arbitrary free-text comment to the Entry
     license : metacatalog.models.License
@@ -133,15 +149,15 @@ class Entry(Base):
 
     # columns
     id = Column(Integer, primary_key=True, autoincrement=True)
+    uuid = Column(String(36), nullable=False, default=lambda: str(uuid4()))
     title = Column(String(512), nullable=False)
     abstract = Column(String)
     external_id = Column(String)
     location = Column(Geometry('POINT'), nullable=False)
     geom = Column(Geometry)
-    creation = Column(DateTime)
-    end = Column(DateTime) # TODO: nachschalgen
     version = Column(Integer, default=1, nullable=False)
     latest_version_id = Column(Integer, ForeignKey('entries.id'), nullable=True)
+    is_partial = Column(Boolean, default=False, nullable=False)
     comment = Column(String, nullable=True)
     
     license_id = Column(Integer, ForeignKey('licenses.id'))
@@ -184,6 +200,7 @@ class Entry(Base):
         # base dictionary
         d = dict(
             id=self.id,
+            uuid=self.uuid,
             title=self.title,
             author=self.author,
             authors=self.authors,
@@ -193,6 +210,7 @@ class Entry(Base):
             embargo=self.embargo,
             embargo_end=self.embargo_end,
             version=self.version,
+            isPartial=self.is_partial,
             publication=self.publication,
             lastUpdate=self.lastUpdate,
             keywords=self.plain_keywords_dict()
@@ -205,7 +223,7 @@ class Entry(Base):
             d['details'] = self.details_dict(full=True)
         
         # set optional attributes
-        for attr in ('abstract', 'external_id','creation','end','comment'):
+        for attr in ('abstract', 'external_id','comment'):
             if hasattr(self, attr) and getattr(self, attr) is not None:
                 d[attr] = getattr(self, attr)
 
